@@ -26,17 +26,13 @@ from sarpy.consistency.sicd_consistency import check_sicd_data_extension
 from sarpy.io.general.nitf import NITFDetails
 from sarpy.io.general.nitf_elements.des import DataExtensionHeader, \
     DataExtensionHeader0
-from sarpy.io.xml.base import parse_xml_from_string
+from sarpy.io.xml.base import parse_xml_from_string, validate_xml_from_string
 from sarpy.io.product.sidd_schema import get_schema_path, get_urn_details, \
     get_specification_identifier
 
 from sarpy.io.product.sidd2_elements.SIDD import SIDDType as SIDDType2
 from sarpy.io.product.sidd1_elements.SIDD import SIDDType as SIDDType1
 
-try:
-    from lxml import etree
-except ImportError:
-    etree = None
 
 logger = logging.getLogger('validation')
 
@@ -55,9 +51,6 @@ def evaluate_xml_versus_schema(xml_string, urn_string):
     bool
     """
 
-    if etree is None:
-        return None
-
     # get schema path
     try:
         the_schema = get_schema_path(urn_string)
@@ -65,14 +58,10 @@ def evaluate_xml_versus_schema(xml_string, urn_string):
         logger.exception('SIDD: Failed finding the schema for urn {}'.format(urn_string))
         return False
 
-    xml_doc = etree.fromstring(xml_string)
-    xml_schema = etree.XMLSchema(file=the_schema)
-    validity = xml_schema.validate(xml_doc)
-    if not validity:
-        for entry in xml_schema.error_log:
-            logger.error('SIDD: schema validation error on line {}'
-                         '\n\t{}'.format(entry.line, entry.message.encode('utf-8')))
-    return validity
+    try:
+        return validate_xml_from_string(xml_string, the_schema, output_logger=logger)
+    except ImportError:
+        return None
 
 
 def _evaluate_xml_string_validity(xml_string=None):
