@@ -10,7 +10,8 @@ from collections import OrderedDict
 from typing import Union
 import numpy
 
-from sarpy.io.xml.base import Serializable, find_children
+from sarpy.io.xml.base import Serializable, find_children, parse_xml_from_file, \
+    parse_xml_from_string
 from sarpy.io.xml.descriptors import SerializableDescriptor, IntegerDescriptor, \
     StringDescriptor
 
@@ -440,3 +441,39 @@ class CRSDType(Serializable):
         if self.PVP is None:
             raise ValueError('No PVP defined.')
         return self.PVP.get_vector_dtype()
+
+    @classmethod
+    def from_xml_file(cls, file_path):
+        """
+        Construct the crsd object from a stand-alone xml file path.
+
+        Parameters
+        ----------
+        file_path : str
+
+        Returns
+        -------
+        CRSDType
+        """
+
+        root_node, xml_ns = parse_xml_from_file(file_path)
+        ns_key = 'default' if 'default' in xml_ns else None
+        return cls.from_node(root_node, xml_ns=xml_ns, ns_key=ns_key)
+
+    @classmethod
+    def from_xml_string(cls, xml_string):
+        """
+        Construct the crsd object from an xml string.
+
+        Parameters
+        ----------
+        xml_string : str|bytes
+
+        Returns
+        -------
+        CRSDType
+        """
+
+        root_node, xml_ns = parse_xml_from_string(xml_string)
+        ns_key = 'default' if 'default' in xml_ns else None
+        return cls.from_node(root_node, xml_ns=xml_ns, ns_key=ns_key)
